# Release information about TGSociable

version = "0.1.0"

description = "A port of the sociable Wordpress plugin"
long_description = """TurboGears Widget to add links to post pages to social bookmarking sites (Digg, Reddit, del.icio.us, &c.)"""
author = "Neil Blakey-Milner, Peter Harkins (original sociable plugin for wordpress)"
email = "nbm@nxsy.org"
copyright = "2007"

# if it's open source, you might want to specify these
url = "http://nxsy.org/code/tgsociable/"
# download_url = "http://yourcool.site/download"
license = "GPL"



import pkg_resources

from turbogears import widgets
import turbogears

resource_dir = pkg_resources.resource_filename("tgsociable",
                                         "static")
widgets.register_static_directory("tgsociable", resource_dir)

from tgsociable.sites import all_sites

class SociableWidget(widgets.Widget):
    template = """
<div class="sociable" xmlns:py="http://purl.org/kid/ns#">
  <span class="sociable_tagline">
    <strong py:content="sociable_tagline">get_option("sociable_tagline");</strong>
    <span py:content="sociable_tagline_description">_("These icons link to social bookmarking sites where readers can share and discover new web pages.", 'sociable')</span>
  </span>

  <ul>  
    <li py:for="site in sites">
      <a py:attrs="site['anchor_attrs']">
        <img py:attrs="site['img_attrs']" />
      </a>
    </li>
  </ul>
</div>
    """

    css = [
        widgets.CSSLink("tgsociable", "css/sociable.css"),
    ]
    javascript = [
        widgets.JSLink("tgsociable", "javascript/description_selection.js"),
    ]

    params_doc = {
        'active_sites' : 'Sites to display sociable icons for',
        'sociable_tagline' : 'Tag line heading',
        'sociable_tagline_description' : 'Tag line explanation',
        'extra_sites' : 'Sites not in the existing sites list that you want to use',
    }
    params = params_doc.keys()

    active_sites = ["Digg", "Reddit", "del.icio.us"]
    sociable_tagline = "Share and Enjoy:"
    sociable_tagline_description = "These icons link to social bookmarking sites where readers can share and discover new web pages."
    extra_sites = {
# Example:
#        'muti': {
#                'favicon': 'http://muti.co.za/images/favicon.ico',
#                'url': 'http://muti.co.za/submit?url=PERMALINK&title=TITLE',
#        },
    }


    def update_params(self, d):
        super(SociableWidget, self).update_params(d)
        active_sites = d['active_sites']
        d['sites'] = []

        my_all_sites = all_sites.copy()
        my_all_sites.update(d['extra_sites'])

        for sitename in active_sites:
            if sitename not in my_all_sites:
                continue

            site = my_all_sites[sitename]

            url = site['url'];
            url = url.replace('PERMALINK', d['post_url'])
            url = url.replace('TITLE', d['post_title'])
            url = url.replace('RSS', d['blog_rss'])
            url = url.replace('BLOGNAME', d['blog_name'])
            sociable_version = "2.0"
            url = url.replace('VERSION', sociable_version)

            anchor_attrs = {}
            anchor_attrs['href'] = url
            if 'description' in site:
                anchor_attrs['onfocus'] = "sociable_description_link(this, '%s')" % (site['description'],)
            img_attrs = {}
            img_attrs['src'] = site['favicon']
            img_attrs['title'] = sitename
            img_attrs['alt'] = sitename
            img_attrs['class'] = "sociable_hovers"
            if 'class' in site:
                img_attrs['class'] += " " + site['class']
            d['sites'].append(dict(anchor_attrs = anchor_attrs, img_attrs = img_attrs))



#!/usr/bin/env python

import sys
import itertools
import re

if len(sys.argv) > 1:
    fp = open(sys.argv[1])
else:
    fp = sys.stdin

lines = fp.readlines()

beg = re.compile('^\$sociable_known_sites')
end = re.compile('^\);')
def find_beginning(item):
    return not beg.match(item)

def find_end(item):
    return not end.match(item)
    
def dropbefore(lines):
    for line in itertools.dropwhile(find_beginning, lines):
        yield line

def dropafter(lines):
    for line in itertools.takewhile(find_end, lines):
        yield line

start_item = re.compile(r"""^\t('[^']*') => Array\(""")
favicon_item = re.compile(r"""\t\t('favicon') => '([^']*)',""")
mid_item = re.compile(r"""\t\t('[^']*') => ('[^']*'),""")
end_item = re.compile(r"""\t\),""")

def start_item_handle(m):
    print "\t%s: {" % (m.groups()[0],)

def favicon_item_handle(m):
    k, v = m.groups()
    print "\t\t%s: turbogears.url('/tg_widgets/tgsociable/images/%s')," % (k, v)

def mid_item_handle(m):
    k, v = m.groups()
    v = v.replace("&amp;", "&")
    print "\t\t%s: %s," % (k, v)

def end_item_handle(m):
    print "\t},"

handlers = [
    (start_item, start_item_handle),
    (favicon_item, favicon_item_handle),
    (mid_item, mid_item_handle),
    (end_item, end_item_handle),
]

def handle_lines(lines):
    for line in dropafter(dropbefore(lines)):
        line = line.rstrip()
        #print line
        for regex, handler in handlers:
            m = regex.search(line)
            if m:
                handler(m)
                break

print "import turbogears"
print "all_sites = {"
handle_lines(lines)
print "}"



try:
    from gibe.plugin import Plugin
except ImportError:
    Plugin = None

if Plugin:
    from tgsociable import SociableWidget

    class SociablePlugin(Plugin):
        def __init__(self):
            self.reconfigure()

        def reconfigure(self):
            extra_sites = {
                'muti': {
                    'favicon': 'http://muti.co.za/images/favicon.ico',
                    'url': 'http://muti.co.za/submit?url=PERMALINK&title=TITLE',
                },
            }

            self.tgsw = SociableWidget(extra_sites = extra_sites, active_sites = ['muti', 'del.icio.us'])

        def post_top_widgets(self, post, wl):
            wl.extend([self.tgsw])



import turbogears
all_sites = {
	'blinkbits': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/blinkbits.png'),
		'url': 'http://www.blinkbits.com/bookmarklets/save.php?v=1&source_url=PERMALINK&title=TITLE&body=TITLE',
	},
	'BlinkList': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/blinklist.png'),
		'url': 'http://www.blinklist.com/index.php?Action=Blink/addblink.php&Url=PERMALINK&Title=TITLE',
	},
	'BlogMemes': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/blogmemes.png'),
		'url': 'http://www.blogmemes.net/post.php?url=PERMALINK&title=TITLE',
	},
	'BlogMemes Fr': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/blogmemes.png'),
		'url': 'http://www.blogmemes.fr/post.php?url=PERMALINK&title=TITLE',
	},
	'BlogMemes Sp': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/blogmemes.png'),
		'url': 'http://www.blogmemes.com/post.php?url=PERMALINK&title=TITLE',
	},
	'BlogMemes Cn': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/blogmemes.png'),
		'url': 'http://www.blogmemes.cn/post.php?url=PERMALINK&title=TITLE',
	},
	'BlogMemes Jp': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/blogmemes.png'),
		'url': 'http://www.blogmemes.jp/post.php?url=PERMALINK&title=TITLE',
	},
	'blogmarks': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/blogmarks.png'),
		'url': 'http://blogmarks.net/my/new.php?mini=1&simple=1&url=PERMALINK&title=TITLE',
	},
	'blogtercimlap': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/blogter.png'),
		'url': 'http://cimlap.blogter.hu/index.php?action=suggest_link&title=TITLE&url=PERMALINK',
	},
	'Blue Dot': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/bluedot.png'),
		'url': 'http://bluedot.us/Authoring.aspx?>u=PERMALINK&title=TITLE',
	},
	'Book.mark.hu': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/bookmarkhu.png'),
		'url': 'http://book.mark.hu/bookmarks.php/?action=add&address=PERMALINK%2F&title=TITLE',
	},
	'Bumpzee': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/bumpzee.png'),
		'url': 'http://www.bumpzee.com/bump.php?u=PERMALINK',
	},
	'co.mments': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/co.mments.gif'),
		'url': 'http://co.mments.com/track?url=PERMALINK&title=TITLE',
	},
	'connotea': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/connotea.png'),
		'url': 'http://www.connotea.org/addpopup?continue=confirm&uri=PERMALINK&title=TITLE',
	},
	'del.icio.us': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/delicious.png'),
		'url': 'http://del.icio.us/post?url=PERMALINK&title=TITLE',
	},
	'De.lirio.us': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/delirious.png'),
		'url': 'http://de.lirio.us/rubric/post?uri=PERMALINK;title=TITLE;when_done=go_back',
	},
	'Digg': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/digg.png'),
		'url': 'http://digg.com/submit?phase=2&url=PERMALINK&title=TITLE',
		'description': 'bodytext',
	},
	'DotNetKicks': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/dotnetkicks.png'),
		'url': 'http://www.dotnetkicks.com/kick/?url=PERMALINK&title=TITLE',
		'description': 'description',
	},
	'DZone': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/dzone.png'),
		'url': 'http://www.dzone.com/links/add.html?url=PERMALINK&title=TITLE',
		'description': 'description',
	},
	'Fark': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/fark.png'),
		'url': 'http://cgi.fark.com/cgi/fark/edit.pl?new_url=PERMALINK&new_comment=TITLE&new_comment=BLOGNAME&linktype=Misc',
	},
	'feedmelinks': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/feedmelinks.png'),
		'url': 'http://feedmelinks.com/categorize?from=toolbar&op=submit&url=PERMALINK&name=TITLE',
	},
	'Furl': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/furl.png'),
		'url': 'http://www.furl.net/storeIt.jsp?u=PERMALINK&t=TITLE',
	},
	'Fleck': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/fleck.gif'),
		'url': 'http://extension.fleck.com/?v=b.0.804&url=PERMALINK',
	},
	'Gwar': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/gwar.gif'),
		'url': 'http://www.gwar.pl/DodajGwar.html?u=PERMALINK',
	},
	'Haohao': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/haohao.png'),
		'url': 'http://www.haohaoreport.com/submit.php?url=PERMALINK&title=TITLE',
	},
	'Hemidemi': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/hemidemi.png'),
		'url': 'http://www.hemidemi.com/user_bookmark/new?title=TITLE&url=PERMALINK',
	},
	'IndiaGram': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/indiagram.png'),
		'url': 'http://www.indiagram.com/mock/bookmarks/desitrain?action=add&address=PERMALINK&title=TITLE',
	},
	'IndianPad': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/indianpad.png'),
		'url': 'http://www.indianpad.com/submit.php?url=PERMALINK',
	},
	'Internetmedia': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/im.png'),
	},
	'kick.ie': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/kickit.png'),
		'url': 'http://kick.ie/submit/?url=PERMALINK&title=TITLE',
	},
	'LinkaGoGo': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/linkagogo.png'),
		'url': 'http://www.linkagogo.com/go/AddNoPopup?url=PERMALINK&title=TITLE',
	},
	'Linkter': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/linkter.png'),
		'url': 'http://www.linkter.hu/index.php?action=suggest_link&url=PERMALINK&title=TITLE',
	},
	'Ma.gnolia': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/magnolia.png'),
		'url': 'http://ma.gnolia.com/bookmarklet/add?url=PERMALINK&title=TITLE',
	},
	'MisterWong': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/misterwong.gif'),
		'url': 'http://www.mister-wong.com/addurl/?bm_url=PERMALINK&bm_description=TITLE&plugin=soc',
	},
	'MyShare': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/myshare.png'),
		'url': 'http://myshare.url.com.tw/index.php?func=newurl&url=PERMALINK&desc=TITLE',
	},
	'NewsVine': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/newsvine.png'),
		'url': 'http://www.newsvine.com/_tools/seed&save?u=PERMALINK&h=TITLE',
	},
	'Netscape': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/netscape.gif'),
		'url': 'http://www.netscape.com/submit/?U=PERMALINK&T=TITLE',
	},
	'Netvouz': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/netvouz.png'),
		'url': 'http://www.netvouz.com/action/submitBookmark?url=PERMALINK&title=TITLE&popup=no',
	},
	'PlugIM': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/plugim.png'),
		'url': 'http://www.plugim.com/submit?url=PERMALINK&title=TITLE',
	},
	'PopCurrent': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/popcurrent.png'),
		'url': 'http://popcurrent.com/submit?url=PERMALINK&title=TITLE&rss=RSS',
	},
	'ppnow': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/ppnow.png'),
		'url': 'http://www.ppnow.net/submit.php?url=PERMALINK',
	},
	'RawSugar': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/rawsugar.png'),
		'url': 'http://www.rawsugar.com/tagger/?turl=PERMALINK&tttl=TITLE',
	},
	'Rec6': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/rec6.gif'),
		'url': 'http://www.syxt.com.br/rec6/link.php?url=PERMALINK&=TITLE',
	},
	'Reddit': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/reddit.png'),
		'url': 'http://reddit.com/submit?url=PERMALINK&title=TITLE',
	},
	'Scoopeo': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/scoopeo.png'),
		'url': 'http://www.scoopeo.com/scoop/new?newurl=PERMALINK&title=TITLE',
	},
	'scuttle': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/scuttle.png'),
		'url': 'http://www.scuttle.org/bookmarks.php/maxpower?action=add&address=PERMALINK&title=TITLE',
	},
	'Shadows': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/shadows.png'),
		'url': 'http://www.shadows.com/features/tcr.htm?url=PERMALINK&title=TITLE',
	},
	'Simpy': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/simpy.png'),
		'url': 'http://www.simpy.com/simpy/LinkAdd.do?href=PERMALINK&title=TITLE&src=sociable-VERSION',
	},
	'Slashdot': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/slashdot.png'),
		'url': 'http://slashdot.org/bookmark.pl?title=TITLE&url=PERMALINK',
	},
	'Smarking': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/smarking.png'),
		'url': 'http://smarking.com/editbookmark/?url=PERMALINK&title=TITLE',
	},
	'Spurl': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/spurl.png'),
		'url': 'http://www.spurl.net/spurl.php?url=PERMALINK&title=TITLE',
	},
	'SphereIt': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/sphere.png'),
		'url': 'http://www.sphere.com/search?q=sphereit:PERMALINK&title=TITLE',
	},
	'StumbleUpon': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/stumbleupon.png'),
		'url': 'http://www.stumbleupon.com/url/PERMALINK',
	},
	'Taggly': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/taggly.png'),
		'url': 'http://taggly.com/bookmarks.php/pass?action=add&address=',
	},
	'Technorati': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/technorati.png'),
		'url': 'http://technorati.com/faves?add=PERMALINK',
	},
	'TailRank': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/tailrank.png'),
		'url': 'http://tailrank.com/share/?text=&link_href=PERMALINK&title=TITLE',
	},
	'ThisNext': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/thisnext.png'),
		'url': 'http://www.thisnext.com/pick/new/submit/sociable/?url=PERMALINK&name=TITLE',
	},
	'Webride': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/webride.png'),
		'url': 'http://webride.org/discuss/split.php?uri=PERMALINK&title=TITLE',
	},
	'Wists': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/wists.png'),
		'url': 'http://wists.com/s.php?c=&r=PERMALINK&title=TITLE',
		'class': 'wists',
	},
	'Wykop': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/wykop.gif'),
		'url': 'http://www.wykop.pl/dodaj?url=PERMALINK',
	},
	'YahooMyWeb': {
		'favicon': turbogears.url('/tg_widgets/tgsociable/images/yahoomyweb.png'),
		'url': 'http://myweb2.search.yahoo.com/myresults/bookmarklet?u=PERMALINK&=TITLE',
	},
}
